# polygon/__init__.py

__app_name__ = "polygon"
__version__ = "0.1.0"

(
    SUCCESS,
    DIR_ERROR,
    FILE_ERROR,
    CONNECT_ERROR,
    SERVER_ERROR,
    JSON_ERROR,
    ID_ERROR,
) = range(7)

ERRORS = {
    DIR_ERROR: "config directory error",
    FILE_ERROR: "config file error",
    CONNECT_ERROR: "connect error",
    SERVER_ERROR: "server error",
    ID_ERROR: "id error",
}



"""This module provides the CLI."""
# cli-module/cli.py
import json
from pathlib import Path
from typing import List, Optional

import sqlparse
import typer
from polygon import __app_name__, __version__, dataset, container,search
from polygon import rest_connect

# import dataset
# import container

app = typer.Typer()
app.add_typer(dataset.app, name="dataset")
app.add_typer(container.app, name="container")


def _version_callback(value: bool) -> None:
    if value:
        typer.echo(f"{__app_name__} v{__version__}")
        raise typer.Exit()


@app.callback()

def main(
    version: Optional[bool] = typer.Option(
        None,
        "--version",
        "-v",
        help="Show the application's version and exit.",
        callback=_version_callback,
        is_eager=True,
    )
) -> None:
    return


@app.command()
def list(
    description: List[str] = typer.Argument(...),
    priority: int = typer.Option(2, "--priority", "-p", min=1, max=3),
) -> None:
    """Add a new to-do with a DESCRIPTION."""
    typer.secho(
        f"""polygon-cli: list """
        f"""with priority: {priority}""",
        fg=typer.colors.GREEN,
    )


@app.command()
def search(phrase: str = typer.Option("None","--phrase",),
           sql: str = typer.Option("None","--sql",),)-> None:
    """Add a new to-do with a DESCRIPTION."""
    typer.secho(
        f"""polygon: search  results """
        f"""pass phrase to search""",
        fg=typer.colors.GREEN,
    )
    if(phrase !="None"):
        searchResult=rest_connect.search_details(phrase)
        print(searchResult)
    else:
        parsedSql=pharsesql(sql)
        searchResult = rest_connect.search_details(phrase,parsedSql)
        print(json.dumps(searchResult, indent=3))

def pharsesql(sql):
    statements = sqlparse.split(sql)
    #print(statements)
    # statements
    # ['select * from foo;', 'select * from bar;']

    # Format the first statement and print it out:
    first = statements[0]
    #print(sqlparse.format(first, reindent=True, keyword_case='upper'))
    # SELECT *
    # FROM foo;

    # Parsing a SQL statement:
    parsed = sqlparse.parse(first)[0]
    #print(parsed.tokens)
    counter = 0
    for tok in parsed.tokens:
        counter = counter + 1
        #print("counter=" + str(counter))
        # print("token="+str(tok))
        IN_WHERE = False
        input_dict = {}
        if tok.is_group:
            for sub_tok in tok.tokens:
                # print("sub_token=" + str(sub_tok))
                if sub_tok.normalized == 'WHERE':
                    IN_WHERE = True
                if IN_WHERE and sub_tok.is_group:
                    # handle where clause
                    #print("sub_token||" + str(sub_tok))
                    #print("sub_token||" + str(sub_tok.value.replace('=', ':')))
                    # strip quotes out
                    input_dict[sub_tok.left.value] = sub_tok.right.value
                    for sub_sub_tok in sub_tok.tokens:
                        k=0
                        #print("sub_sub_tok=" + str(sub_sub_tok))
                        # pass

    input_json_data = json.dumps(input_dict)
    return input_json_data
# @app.command()
# def dataset(
#     description: List[str] = typer.Argument(...),
#     priority: int = typer.Option(2, "--priority", "-p", min=1, max=3),
# ) -> None:
#     """Add a new to-do with a DESCRIPTION."""
#     typer.secho(
#         f"""polygon-cli: list """
#         f"""with priority: {priority}""",
#         fg=typer.colors.GREEN,
#     )



# @app.command()
# def container(
#     description: List[str] = typer.Argument(...),
#     priority: int = typer.Option(2, "--priority", "-p", min=1, max=3),
# ) -> None:
#     """Add a new to-do with a DESCRIPTION."""
#     typer.secho(
#         f"""polygon-cli: list """
#         f"""with priority: {priority}""",
#         fg=typer.colors.GREEN,
#     )




"""This module provides the CLI."""
# cli-module/cli.py
import json
from typing import List, Optional
from polygon import rest_connect

import typer

app = typer.Typer()


@app.command()
def list():
    typer.echo(f"list")
    #call the endpoint to get list of clod containers
    #rest-connect with the json
    containerList=rest_connect.containerList()
    print(json.dumps(containerList, indent=3))


@app.command()
def add(cloudstoragename:str = typer.Option("None","--cloudstoragename","--n"),
    cloudtype: str = typer.Option("None","--cloudtype",),
    authentication: str = typer.Option("None","--authentication",),
    containername: str = typer.Option("None","--containername",),
    bucketname: str = typer.Option("None","--bucketname",),
    accontname: str = typer.Option("None","--accontname",),
    accesskey: str = typer.Option("None","--accesskey",),
    secretid: str = typer.Option("None","--secretid",),
    sastoken: str = typer.Option("None","--sastoken",),
    manifestjson: str = typer.Option("None","--manifestjson",),
    region: str = typer.Option("None","--region",),
) -> None:

    if (cloudtype == "aws_s3" and authentication == "account_authentication"):
        if (bucketname == "None" or accesskey == "None" or secretid == "None" or region == "None"):
            print("Please provide proper cloud details'")
        else:
            dataseDetails=rest_connect.createContainer(cloudstoragename,cloudtype,authentication,containername,bucketname,
                                                   accontname,accesskey,secretid,sastoken,manifestjson,region)
            print(dataseDetails)
    if (cloudtype == "aws_s3" and authentication == "annonymous_access"):
        if (bucketname == "None" or manifestjson == "None" or region == "None"):
            print("Please provide proper cloud details'")
        else:
            dataseDetails = rest_connect.createContainer(cloudstoragename, cloudtype, authentication, containername,
                                                       bucketname,
                                                       accontname, accesskey, secretid, sastoken, manifestjson, region)
            print(dataseDetails)
    if (cloudtype == "azure_container" and authentication == "account_authentication"):
        if (containername == "None" or accontname == "None" or sastoken == "None"):
            print("Please provide proper cloud details'")
        else:
            dataseDetails = rest_connect.createContainer(cloudstoragename, cloudtype, authentication, containername,
                                                       bucketname,
                                                       accontname, accesskey, secretid, sastoken, manifestjson, region)
            print(dataseDetails)
    if (cloudtype == "azure_container" and authentication == "annonymous_access"):
        if (containername == "None" or accontname == "None"):
            print("Please provide proper cloud details'")
        else:
            dataseDetails = rest_connect.createContainer(cloudstoragename, cloudtype, authentication, containername,
                                                       bucketname,
                                                       accontname, accesskey, secretid, sastoken, manifestjson, region)
            print(dataseDetails)

@app.command()
def details(cloudstoragename:str = typer.Option("None","--cloudstoragename","--n"),
    cloudstorageid: str = typer.Option("None","--cloudstorageid",),
) -> None:
    datasetDetails = rest_connect.container_details(cloudstoragename, cloudstorageid)
    print(datasetDetails)


@app.command()
def delete(name:str = typer.Option("None","--name","--n"),
    id: str = typer.Option("None","--id",),
) -> None:
    datasetDetails = rest_connect.delete_container(name, id)
    print(datasetDetails)


if __name__ == "__main__":
    app()
